@@ -217,12 +217,4 @@ class Extractor(object):
                 logging.warning(f'Retrying {tries} of {max_retries}')
 
         if tries == max_retries:
-            raise TimeoutError('Too many retries')
-
-
-
-import pandas as pd
-
-a =  pd.DataFrame([{'a': 1, 'b': 2}])
-
-a.to_csv('a.csv')
\ No newline at end of file
+            raise TimeoutError('Too many retries')
\ No newline at end of file
